@@ -95,7 +95,10 @@ class DownloadProgress(QtCore.QObject, BaseMeter):
     """
     def start(self, filename=None, url=None, basename=None, size=None,
               now=None, text=None):
-        self.emit(QtCore.SIGNAL("maxprogress(int)"), size)
+        if (size==None):
+          self.emit(QtCore.SIGNAL("maxprogress(int)"), 0)
+        else:
+          self.emit(QtCore.SIGNAL("maxprogress(int)"), size)
 
     def update(self, amount_read, now=None):
         """ Update our download progressbar.
